summaryrefslogtreecommitdiffstats
path: root/karbon/core/vgroup.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /karbon/core/vgroup.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/core/vgroup.h')
-rw-r--r--karbon/core/vgroup.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/karbon/core/vgroup.h b/karbon/core/vgroup.h
index 25190178..29eb3842 100644
--- a/karbon/core/vgroup.h
+++ b/karbon/core/vgroup.h
@@ -20,12 +20,12 @@
#ifndef __VGROUP_H__
#define __VGROUP_H__
-#include <qptrlist.h>
+#include <tqptrlist.h>
#include "vobject.h"
#include <koffice_export.h>
-typedef QPtrList<VObject> VObjectList;
-typedef QPtrListIterator<VObject> VObjectListIterator;
+typedef TQPtrList<VObject> VObjectList;
+typedef TQPtrListIterator<VObject> VObjectListIterator;
/**
* Base class for all sort of VObject conglomerats.
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
{
public:
/**
* Constructs a new group object that is child of parent and has the given state.
*
* The object's fill and stroke are created here.
*
* @param parent the new object's parent
* @param state the new object's state
*/
- VGroup( VObject* parent, VState state = normal );
+ VGroup( VObject* tqparent, VState state = normal );
/**
* Copy constructor.
@@ -65,10 +65,10 @@ public:
virtual void setState( const VState state );
- virtual void save( QDomElement& element ) const;
+ virtual void save( TQDomElement& element ) const;
virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles, int &index ) const;
- virtual void load( const QDomElement& element );
- virtual bool loadOasis( const QDomElement &element, KoOasisLoadingContext &context );
+ virtual void load( const TQDomElement& element );
+ virtual bool loadOasis( const TQDomElement &element, KoOasisLoadingContext &context );
virtual VGroup* clone() const;
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
public:
/**
- * Constructs a new group object that is child of parent and has the given state.
+ * Constructs a new group object that is child of tqparent and has the given state.
*
* The object's fill and stroke are created here.
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
* The object's fill and stroke are created here.
*
- * @param parent the new object's parent
+ * @param tqparent the new object's tqparent
* @param state the new object's state
*/